'use strict';
var yeoman = require('yeoman-generator');
var chalk = require('chalk');
var yosay = require('yosay');
var git = require('gulp-git');

module.exports = yeoman.Base.extend({

  prompting: function () {
    // Have Yeoman greet the user.
    this.log(yosay(
      'Welcome to the posh ' + chalk.red('generator-docs-scaffold') + ' generator!'
    ));

    var prompts = [{
      type: 'input',
      name: 'url',
      message: 'git url for the repo',
      default: 'http://stash.verizon.com/scm/npdirvui/ts-docs-base.git'
    },{
      type: 'input',
      name: 'branch',
      message: 'git branch for the repo',
      default: 'master'
    },{
      type: 'input',
      name: 'name',
      message: 'Name of the Repo',
      default: 'docs-base'
    },{
      type: 'input',
      name: 'friendly_name',
      message: 'Friendly Name of the Repo',
      default: 'Documentation Help'
    }];

    return this.prompt(prompts).then(function (props) {
      // To access props later use this.props.someAnswer;
      console.log(props);
      this.props = props;
      this.props.sharedPath = process.cwd()
      console.log('**********************');
      console.log(this.props.sharedPath);
      console.log('******** end ********');

      var options = {
        args: ' ' + '\'' + './src/' + '\''  + ' -b ' + this.props.branch,
        quiet: true,
      };
      this.props.sharedPath = process.cwd() + '/src';

      git.clone(this.props.url,options,function (err) {
        if (err) {
          console.log(err);
        }
        else{
          console.log('Cloning done');
        }
      });

    }.bind(this));
  },

  writing: function () {
    this.fs.copyTpl(
      this.templatePath('_config.json'),
      this.destinationPath('config.json'), {
        name: this.props.name,
        url: this.props.url,
        friendly_name:this.props.friendly_name,
        branch: this.props.branch
      }
    );

    this.fs.copyTpl(
      this.templatePath('_config.yml'),
      this.destinationPath('config.yml'), {
        name: this.props.name,
        url: this.props.url,
        friendly_name:this.props.friendly_name,
        branch: this.props.branch
      }
    );
    this.fs.copy(
      this.templatePath('_Dockerfile'),
      this.destinationPath('Dockerfile')
    );
    this.fs.copy(
      this.templatePath('_editorconfig'),
      this.destinationPath('.editorconfig')
    );
    this.fs.copyTpl(
      this.templatePath('_package.json'),
      this.destinationPath('package.json'), {
        name: this.props.name,
        sharedPath: this.props.sharedPath
      }
    );
    this.fs.copyTpl(
      this.templatePath('_docker-compose.yml'),
      this.destinationPath('docker-compose.yml'), {
        name: this.props.name,
        sharedPath: this.props.sharedPath
      }
    );
  },
  install: function () {
    this.npmInstall()
  }
});
